BinanceSpotRest.Endpoints.Account.MyTrades.Query (Binance Spot Rest v0.2.1)

My Trades

Account trade list (USER_DATA)

GET /api/v3/myTrades

Get trades for a specific account and symbol.

Weight:

ConditionWeight
Without orderId20
With orderId5

Parameters:

NameTypeMandatoryDescription
symbolSTRINGYES
orderIdLONGNOThis can only be used in combination with symbol.
startTimeLONGNO
endTimeLONGNO
fromIdLONGNOTradeId to fetch from. Default gets most recent trades.
limitINTNODefault: 500; Maximum: 1000.
recvWindowDECIMALNOThe value cannot be greater than 60000. Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
timestampLONGYES

Notes:

  • If fromId is set, it will get trades >= that fromId. Otherwise most recent trades are returned.
  • The time between startTime and endTime can't be longer than 24 hours.
  • These are the supported combinations of all parameters:
  • symbol
  • symbol + orderId
  • symbol + startTime
  • symbol + endTime
  • symbol + fromId
  • symbol + startTime + endTime
  • symbol+ orderId + fromId

Data Source: Memory => Database

Response:

[
  {
    "symbol": "BNBBTC",
    "id": 28457,
    "orderId": 100234,
    "orderListId": -1,
    "price": "4.00000100",
    "qty": "12.00000000",
    "quoteQty": "48.000012",
    "commission": "10.10000000",
    "commissionAsset": "BNB",
    "time": 1499865549590,
    "isBuyer": true,
    "isMaker": false,
    "isBestMatch": true
  }
]