BinanceSpotRest.Endpoints.Trading.OpenOrdersDelete.Query (Binance Spot Rest v0.2.1)

Open Orders (delete)

Cancel All Open Orders on a Symbol (TRADE)

DELETE /api/v3/openOrders

Cancels all active orders on a symbol. This includes orders that are part of an order list.

Weight: 1

Parameters:

NameTypeMandatoryDescription
symbolSTRINGYES
recvWindowDECIMALNOThe value cannot be greater than 60000. Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
timestampLONGYES

Data Source: Matching Engine

Full docs: Binance API – openOrders DELETE