BinanceSpotRest.Endpoints.Trading.OrderCancelReplacePost.StopLossLimitQuery (Binance Spot Rest v0.2.1)

Order Cancel Replace (post) - Stop loss limit query

Cancel an Existing Order and Send a New Order (TRADE)

POST /api/v3/order/cancelReplace

Cancels an existing order and places a new order on the same symbol.

Filters and Order Count are evaluated before the processing of the cancellation and order placement occurs.

A new order that was not attempted (i.e. when newOrderResult: NOT_ATTEMPTED ), will still increase the order count by 1.

Weight: 1

Parameters - same as order

Parameters - aditional (endpoint specific):

NameTypeMandatoryDescription
cancelReplaceModeENUMYESThe allowed values are: <br/> STOP_ON_FAILURE - If the cancel request fails, the new order placement will not be attempted. <br/> ALLOW_FAILURE - new order placement will be attempted even if cancel request fails.
cancelNewClientOrderIdSTRINGNOUsed to uniquely identify this cancel. Automatically generated by default.
cancelOrigClientOrderIdSTRINGNOEither the cancelOrigClientOrderId or cancelOrderId must be provided. If both are provided, cancelOrderId takes precedence.
cancelOrderIdLONGNOEither the cancelOrigClientOrderId or cancelOrderId must be provided. If both are provided, cancelOrderId takes precedence.
cancelRestrictionsENUMNOSupported values: <br>ONLY_NEW - Cancel will succeed if the order status is NEW.<br> ONLY_PARTIALLY_FILLED - Cancel will succeed if order status is PARTIALLY_FILLED. For more information please refer to Regarding cancelRestrictions
orderRateLimitExceededModeENUMNoSupported values: <br> DO_NOTHING (default)- will only attempt to cancel the order if account has not exceeded the unfilled order rate limit<br> CANCEL_ONLY - will always cancel the order

Similar to POST /api/v3/order, additional mandatory parameters are determined by type.

Response format varies depending on whether the processing of the message succeeded, partially succeeded, or failed.

Data Source: Matching Engine

Full docs: Binance API – order/cancelReplace