BinanceSpotRest.Endpoints.Trading.OrderListDelete.Query (Binance Spot Rest v0.2.1)

Order List (delete)

Cancel Order list (TRADE)

DELETE /api/v3/orderList

Cancel an entire Order list

Weight: 1

Parameters:

NameTypeMandatoryDescription
symbolSTRINGYES
orderListIdLONGNOEither orderListId or listClientOrderId must be provided
listClientOrderIdSTRINGNOEither orderListId or listClientOrderId must be provided
newClientOrderIdSTRINGNOUsed to uniquely identify this cancel. Automatically generated by default
recvWindowDECIMALNOThe value cannot be greater than 60000. Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
timestampLONGYES

Notes:

  • Canceling an individual order from an order list will cancel the entire order list.
  • If both orderListId and listClientOrderId parameters are provided, the orderListId is searched first, then the listClientOrderId from that result is checked against that order. If both conditions are not met the request will be rejected.

Data Source: Matching Engine

Full docs: Binance API – orderList DELETE