BinanceSpotRest.Endpoints.Trading.OrderListOtoPost.WorkingLimitPendingMarketQuery (Binance Spot Rest v0.2.1)

Order List Oto (post) - Working limit pending market query

New Order list - OTO (TRADE)

POST /api/v3/orderList/oto

Place an OTO.

  • An OTO (One-Triggers-the-Other) is an order list comprised of 2 orders.
  • The first order is called the working order and must be LIMIT or LIMIT_MAKER. Initially, only the working order goes on the order book.
  • The second order is called the pending order. It can be any order type except for MARKET orders using parameter quoteOrderQty. The pending order is only placed on the order book when the working order gets fully filled.
  • If either the working order or the pending order is cancelled individually, the other order in the order list will also be canceled or expired.
  • When the order list is placed, if the working order gets immediately fully filled, the placement response will show the working order as FILLED but the pending order will still appear as PENDING_NEW. You need to query the status of the pending order again to see its updated status.
  • OTOs add 2 orders to the EXCHANGE_MAX_NUM_ORDERS filter and MAX_NUM_ORDERS filter.

Weight: 1

Unfilled Order Count: 2

Parameters:

NameTypeMandatoryDescription
symbolSTRINGYES
listClientOrderIdSTRINGNOArbitrary unique ID among open order lists. Automatically generated if not sent. <br>A new order list with the same listClientOrderId is accepted only when the previous one is filled or completely expired. <br> listClientOrderId is distinct from the workingClientOrderId and the pendingClientOrderId.
newOrderRespTypeENUMNOFormat of the JSON response. Supported values: [Order Response Type]
selfTradePreventionModeENUMNOThe allowed values are dependent on what is configured on the symbol. Supported values: [STP Modes]
workingTypeENUMYESSupported values: LIMIT,LIMIT_MAKER
workingSideENUMYESSupported values: [Order Side]
workingClientOrderIdSTRINGNOArbitrary unique ID among open orders for the working order.<br> Automatically generated if not sent.
workingPriceDECIMALYES
workingQuantityDECIMALYESSets the quantity for the working order.
workingIcebergQtyDECIMALNOThis can only be used if workingTimeInForce is GTC, or if workingType is LIMIT_MAKER.
workingTimeInForceENUMNOSupported values: [Time In Force]
workingStrategyIdLONGNOArbitrary numeric value identifying the working order within an order strategy.
workingStrategyTypeINTNOArbitrary numeric value identifying the working order strategy. <br> Values smaller than 1000000 are reserved and cannot be used.
pendingTypeENUMYESSupported values: Order Types<br> Note that MARKET orders using quoteOrderQty are not supported.
pendingSideENUMYESSupported values: [Order Side]
pendingClientOrderIdSTRINGNOArbitrary unique ID among open orders for the pending order.<br> Automatically generated if not sent.
pendingPriceDECIMALNO
pendingStopPriceDECIMALNO
pendingTrailingDeltaDECIMALNO
pendingQuantityDECIMALYESSets the quantity for the pending order.
pendingIcebergQtyDECIMALNOThis can only be used if pendingTimeInForce is GTC or if pendingType is LIMIT_MAKER.
pendingTimeInForceENUMNOSupported values: [Time In Force]
pendingStrategyIdLONGNOArbitrary numeric value identifying the pending order within an order strategy.
pendingStrategyTypeINTNOArbitrary numeric value identifying the pending order strategy. <br> Values smaller than 1000000 are reserved and cannot be used.
recvWindowDECIMALNOThe value cannot be greater than 60000. Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified.
timestampLONGYES

Mandatory parameters based on pendingType or workingType

Depending on the pendingType or workingType, some optional parameters will become mandatory.

TypeAdditional mandatory parametersAdditional information
workingType = LIMITworkingTimeInForce
pendingType = LIMITpendingPrice, pendingTimeInForce
pendingType = STOP_LOSS or TAKE_PROFITpendingStopPrice and/or pendingTrailingDelta
pendingType = STOP_LOSS_LIMIT or TAKE_PROFIT_LIMITpendingPrice, pendingStopPrice and/or pendingTrailingDelta, pendingTimeInForce

Data Source:

Matching Engine

Full docs: Binance API – orderList/oto POST