BinanceSpotRest.Enums.CancelReplaceMode (Binance Spot Rest v0.2.1)

Defines cancel-replace modes for Binance Spot orders.

This enum corresponds to the cancelReplaceMode parameter in the Binance API – Cancel an Existing Order and Send a New Order (TRADE).

Supported values:

  • :STOP_ON_FAILURE – If the cancel request fails, the new order placement will not be attempted.
  • :ALLOW_FAILURE – The new order placement will be attempted even if the cancel request fails.

Summary

Functions

all()

keys()

values()