BinanceSpotRest.Enums.NewOrderRespType (Binance Spot Rest v0.2.1)

Defines the response type for new order requests.

This enum corresponds to the newOrderRespType parameter in the Binance API – New Order (TRADE).

Supported values:

  • :ACK – Order accepted and immediately acknowledged. Only orderId is returned.
  • :RESULT – Order accepted and result is returned, including order details such as symbol, order type, side, etc.
  • :FULL – Order accepted and full order information is returned, including fills.

Summary

Functions

all()

keys()

values()