BinanceSpotRest.Enums.OrderRateLimitExceededMode (Binance Spot Rest v0.2.1)

Defines the behavior when an order rate limit is exceeded.

This enum corresponds to the orderRateLimitExceededMode field in the POST /api/v3/order/cancelReplace.

Supported values:

  • :DO_NOTHING – No special action is taken when the rate limit is exceeded.
  • :CANCEL_ONLY – Account is restricted to cancel-only mode; new orders are not allowed, but existing open orders can still be canceled.

Summary

Functions

all()

keys()

values()