BinanceSpotRest.Enums.SelfTradePreventionMode (Binance Spot Rest v0.2.1)

Defines self-trade prevention modes for Binance Spot orders.

This enum corresponds to the selfTradePreventionMode parameter in the Binance API – New Order (TRADE).

Supported values:

  • :NONE – No self-trade prevention is applied.
  • :EXPIRE_MAKER – If a new order would match an existing order from the same account, the maker order is canceled.
  • :EXPIRE_TAKER – If a new order would match an existing order from the same account, the taker order is canceled.
  • :EXPIRE_BOTH – If a new order would match an existing order from the same account, both orders are canceled.

More info: Self Trade Prevention (STP) FAQ

Summary

Functions

all()

keys()

values()