BinanceSpotRest.Enums.SymbolStatus (Binance Spot Rest v0.2.1)

Defines the trading status of a symbol in the Binance Spot market.

This enum corresponds to the status field in the Binance API – Exchange Information.

Supported values:

  • :TRADING – The symbol is active and trading is allowed.
  • :HALT – Trading for the symbol is temporarily halted.
  • :BREAK – Trading for the symbol is in a break period and not allowed.

Summary

Functions

all()

keys()

values()