BinanceSpotRest.Enums.Type (Binance Spot Rest v0.2.1)

Defines symbol quote types for the Binance Spot market.

For example this enum corresponds to the type parameter in the Binance API – Rolling window price change statistics.

And other endpoints with type parameter.

Supported values:

  • :FULL – Full symbol information including all trading details.
  • :MINI – Minimal symbol information with essential details only.

Summary

Functions

all()

keys()

values()