BinanceSpotRest.Endpoints.MarketData.TickerTradingDay.SymbolQuery (Binance Spot Rest v0.2.1)
View SourceTicker Trading Day - Symbol query
Trading Day Ticker
GET /api/v3/ticker/tradingDayPrice change statistics for a trading day.
Weight:
4 for each requested <tt>symbol</tt>. <br/><br/> The weight for this request will cap at 200 once the number of symbols in the request is more than 50.
Notes:
- Supported values for
timeZone: - Hours and minutes (e.g.
-1:00,05:45) - Only hours (e.g.
0,8,4)
Data Source: Database
Full docs: Binance API – ticker/tradingDay