BinanceSpotRest.Endpoints.Trading.OpenOrdersDelete.Query (Binance Spot Rest v0.2.1)
View SourceOpen Orders (delete)
Cancel All Open Orders on a Symbol (TRADE)
DELETE /api/v3/openOrdersCancels all active orders on a symbol. This includes orders that are part of an order list.
Weight: 1
Parameters:
| Name | Type | Mandatory | Description |
|---|---|---|---|
| symbol | STRING | YES | |
| recvWindow | DECIMAL | NO | The value cannot be greater than 60000. Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified. |
| timestamp | LONG | YES |
Data Source: Matching Engine
Full docs: Binance API – openOrders DELETE