BinanceSpotRest.Endpoints.Trading.OrderListDelete.Query (Binance Spot Rest v0.2.1)
View SourceOrder List (delete)
Cancel Order list (TRADE)
DELETE /api/v3/orderListCancel an entire Order list
Weight: 1
Parameters:
| Name | Type | Mandatory | Description |
|---|---|---|---|
| symbol | STRING | YES | |
| orderListId | LONG | NO | Either orderListId or listClientOrderId must be provided |
| listClientOrderId | STRING | NO | Either orderListId or listClientOrderId must be provided |
| newClientOrderId | STRING | NO | Used to uniquely identify this cancel. Automatically generated by default |
| recvWindow | DECIMAL | NO | The value cannot be greater than 60000. Supports up to three decimal places of precision (e.g., 6000.346) so that microseconds may be specified. |
| timestamp | LONG | YES |
Notes:
- Canceling an individual order from an order list will cancel the entire order list.
- If both
orderListIdandlistClientOrderIdparameters are provided, theorderListIdis searched first, then thelistClientOrderIdfrom that result is checked against that order. If both conditions are not met the request will be rejected.
Data Source: Matching Engine
Full docs: Binance API – orderList DELETE