BinanceSpotRest.Endpoints.Trading.OrderListOtocoPost.WorkingLimitMakerPendingAboveStopLossLimitBelowTakeProfitLimitQuery (Binance Spot Rest v0.2.1)
View SourceOrder List Otoco (post) - Working limit maker pending above stop loss limit below take profit limit query
New Order list - OTOCO (TRADE)
POST /api/v3/orderList/otocoPlace an OTOCO.
- An OTOCO (One-Triggers-One-Cancels-the-Other) is an order list comprised of 3 orders.
- The first order is called the working order and must be
LIMITorLIMIT_MAKER. Initially, only the working order goes on the order book. - The behavior of the working order is the same as the OTO.
- OTOCO has 2 pending orders (pending above and pending below), forming an OCO pair. The pending orders are only placed on the order book when the working order gets fully filled.
- The rules of the pending above and pending below follow the same rules as the Order list OCO.
- OTOCOs add 3 orders to the
EXCHANGE_MAX_NUM_ORDERSfilter andMAX_NUM_ORDERSfilter.
Weight: 1
Unfilled Order Count: 3
Data Source:
Matching Engine
Full docs: Binance API – orderList/otoco POST