BinanceSpotRest.Enums.CancelRestrictions (Binance Spot Rest v0.2.1)
View SourceDefines cancel restrictions for Binance Spot orders.
This enum is used in the Cancel order (TRADE) and Cancel an Existing Order and Send a New Order (TRADE) endpoints.
Supported values:
:ONLY_NEW– Cancel will succeed only if the order status isNEW.:ONLY_PARTIALLY_FILLED– Cancel will succeed only if the order status isPARTIALLY_FILLED. For more details, see Regarding cancelRestrictions.