BinanceSpotRest.Enums.TimeInForce (Binance Spot Rest v0.2.1)
View SourceDefines the time-in-force options for Binance Spot orders.
This enum corresponds to the timeInForce parameter in the
Binance API – New Order (TRADE).
Supported values:
:GTC– Good Till Canceled. The order remains active on the book until it is canceled.:IOC– Immediate Or Cancel. The order will attempt to fill as much as possible immediately, and any unfilled portion is canceled.:FOK– Fill Or Kill. The order must be filled in its entirety immediately, or it is canceled.